@@ -2,6 +2,7 @@ import           Control.Monad (unless)
 import           System.IO (BufferMode(..), hSetBuffering, stdout, stderr)
 import           System.Exit (exitFailure)
 
+import qualified Test.Hedgehog.Seed
 import qualified Test.Hedgehog.Text
 
 
@@ -12,6 +13,7 @@ main = do
 
   results <- sequence [
       Test.Hedgehog.Text.tests
+    , Test.Hedgehog.Seed.tests
     ]
 
   unless (and results) $
